summaryrefslogtreecommitdiff
path: root/utils
diff options
context:
space:
mode:
Diffstat (limited to 'utils')
-rw-r--r--utils/messages.c8
-rw-r--r--utils/messages.h19
2 files changed, 23 insertions, 4 deletions
diff --git a/utils/messages.c b/utils/messages.c
index 78b9a79f0..91b41cbc8 100644
--- a/utils/messages.c
+++ b/utils/messages.c
@@ -142,7 +142,7 @@ messages_get_ctx(const char *key, struct hash_table *ctx)
}
/* exported interface documented in messages.h */
-nserror messages_load(const char *path)
+nserror messages_add_from_file(const char *path)
{
nserror err;
@@ -158,6 +158,12 @@ nserror messages_load(const char *path)
}
/* exported interface documented in messages.h */
+nserror messages_add_from_inline(const char *data)
+{
+ return NSERROR_OK;
+}
+
+/* exported interface documented in messages.h */
char *messages_get_buff(const char *key, ...)
{
const char *msg_fmt;
diff --git a/utils/messages.h b/utils/messages.h
index c9946e6a9..4d04cd52b 100644
--- a/utils/messages.h
+++ b/utils/messages.h
@@ -38,13 +38,26 @@
/**
* Read keys and values from messages file into the standard Messages hash.
*
* The messages are merged with any previously loaded messages. Any keys which
* are present already are replaced with the new value.
*
* \param path pathname of messages file.
* \return NSERROR_OK on success or error code on faliure.
*/
-nserror messages_load(const char *path);
+nserror messages_add_from_file(const char *path);
+
+/**
+ * Read keys and values from inline message data into the standard Messages hash.
+ *
+ * The messages are merged with any previously loaded messages. Any
+ * keys which are present already are replaced with the new value. The
+ * data may be gzip compressed.
+ *
+ * \param data The inline message data.
+ * \return NSERROR_OK on success or error code on faliure.
+ */
+nserror messages_add_from_inline(const char *data);
/**
* Fast lookup of a message by key from the standard Messages hash.
@@ -38,13 +38,26 @@
* Read keys and values from messages file into the standard Messages hash.
*
- * The messages are merged with any previously loaded messages. Any keys which
- * are present already are replaced with the new value.
+ * The messages are merged with any previously loaded messages. Any
+ * keys which are present already are replaced with the new value. The
+ * file may be gzip compressed.
*
* \param path pathname of messages file.